

# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of choice confidence?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory
digits  <- 2 # number of digits to show after the decimal point.

source("functions.R")

afterDM_data <- read.csv("results/VAandDSS - Post-response (Responses) - Form Responses 1_p21.csv") 
afterDM_confidence_data <- subset(afterDM_data, select = c("Participant.ID", "confidence", "technique"))
#afterDM_confidence_data[,"confidence"] <-afterDM_confidence_data[,"confidence"]/10
afterDM_confidence_data_PC <- subset(afterDM_confidence_data, technique=="PC")
afterDM_confidence_data_SM <- subset(afterDM_confidence_data, technique=="SM")
afterDM_confidence_data_TV <- subset(afterDM_confidence_data, technique=="TV")

#afterDM_confidence_data <- cbind(afterDM_data[,"Participant ID"], afterDM_data[,"confidence"]/10)

confidenceDM_diff_PC_SM_CI  <- meanCI(afterDM_confidence_data_PC[,"confidence"] - afterDM_confidence_data_SM[,"confidence"]) 
confidenceDM_diff_PC_TV_CI  <- meanCI(afterDM_confidence_data_PC[,"confidence"] - afterDM_confidence_data_TV[,"confidence"]) 
confidenceDM_diff_SM_TV_CI  <- meanCI(afterDM_confidence_data_SM[,"confidence"] - afterDM_confidence_data_TV[,"confidence"]) 

confidenceDM_PC_CI  <- meanCI(afterDM_confidence_data_PC[,"confidence"]) 
confidenceDM_SM_CI  <- meanCI(afterDM_confidence_data_SM[,"confidence"]) 
confidenceDM_TV_CI  <- meanCI( afterDM_confidence_data_TV[,"confidence"]) 

# Ploting all CI
results <- data.frame(label = "DM PC confidence" , point = confidenceDM_PC_CI[1], ci.lower = confidenceDM_PC_CI[2], ci.upper = confidenceDM_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "DM SM confidence" , point = confidenceDM_SM_CI[1], ci.lower = confidenceDM_SM_CI[2], ci.upper = confidenceDM_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM TV confidence" , point = confidenceDM_TV_CI[1], ci.lower = confidenceDM_TV_CI[2], ci.upper = confidenceDM_TV_CI[3], type='Other'))  

results2 <- data.frame(label = "DM PC-SM confidence Difference " , point = confidenceDM_diff_PC_SM_CI[1], ci.lower = confidenceDM_diff_PC_SM_CI[2], ci.upper = confidenceDM_diff_PC_SM_CI[3], type='Other')
results2 <- rbind(results2, data.frame(label = "DM PC-TV confidence Difference " , point = confidenceDM_diff_PC_TV_CI[1], ci.lower = confidenceDM_diff_PC_TV_CI[2], ci.upper = confidenceDM_diff_PC_TV_CI[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "DM SM-TV confidence Difference " , point = confidenceDM_diff_SM_TV_CI[1], ci.lower = confidenceDM_diff_SM_TV_CI[2], ci.upper = confidenceDM_diff_SM_TV_CI[3], type='Other'))  

plot    <- plotAllCI_likertScale(results)
plot

plot    <- plotAllCI(results2, plotRange = c(-4, 4))
plot

# Printing exact values
confidenceDM_diff_PC_SM_CIform  <- format_ci( confidenceDM_diff_PC_SM_CI, digits, width = NA, FALSE)
confidenceDM_diff_PC_TV_CIform  <- format_ci( confidenceDM_diff_PC_TV_CI, digits, width = NA, FALSE)
confidenceDM_diff_SM_TV_CIform  <- format_ci( confidenceDM_diff_SM_TV_CI, digits, width = NA, FALSE)

confidenceDM_PC_CIform  <- format_ci( confidenceDM_PC_CI, digits, width = NA, FALSE)
confidenceDM_SM_CIform  <- format_ci( confidenceDM_SM_CI, digits, width = NA, FALSE)
confidenceDM_TV_CIform  <- format_ci( confidenceDM_TV_CI, digits, width = NA, FALSE)

cat("\n1.# How do the three techniques perform in terms of choice confidence?")
cat("\n2. DM confidence PC : ",confidenceDM_PC_CIform)
cat("\n2. DM confidence SM: " ,confidenceDM_SM_CIform)
cat("\n2. DM confidence TV: " ,confidenceDM_TV_CIform)
cat("\n2. DM confidence Difference PC-SM: ",confidenceDM_diff_PC_SM_CIform)
cat("\n2. DM confidence Difference PC-TV: ",confidenceDM_diff_PC_TV_CIform)
cat("\n2. DM confidence Difference SM-TV: ",confidenceDM_diff_SM_TV_CIform)

