

# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of choice satisfaction?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory
digits  <- 2 # number of digits to show after the decimal point.

source("functions.R")

afterDM_data <- read.csv("results/VAandDSS - Post-response (Responses) - Form Responses 1_p21.csv") 
afterDM_satisfaction_data <- subset(afterDM_data, select = c("Participant.ID", "satisfaction", "technique"))
#afterDM_satisfaction_data[,"satisfaction"] <-afterDM_satisfaction_data[,"satisfaction"]/10
afterDM_satisfaction_data_PC <- subset(afterDM_satisfaction_data, technique=="PC")
afterDM_satisfaction_data_SM <- subset(afterDM_satisfaction_data, technique=="SM")
afterDM_satisfaction_data_TV <- subset(afterDM_satisfaction_data, technique=="TV")

#afterDM_satisfaction_data <- cbind(afterDM_data[,"Participant ID"], afterDM_data[,"satisfaction"]/10)

satisfactionDM_diff_PC_SM_CI  <- meanCI(afterDM_satisfaction_data_PC[,"satisfaction"] - afterDM_satisfaction_data_SM[,"satisfaction"]) 
satisfactionDM_diff_PC_TV_CI  <- meanCI(afterDM_satisfaction_data_PC[,"satisfaction"] - afterDM_satisfaction_data_TV[,"satisfaction"]) 
satisfactionDM_diff_SM_TV_CI  <- meanCI(afterDM_satisfaction_data_SM[,"satisfaction"] - afterDM_satisfaction_data_TV[,"satisfaction"]) 

satisfactionDM_PC_CI  <- meanCI(afterDM_satisfaction_data_PC[,"satisfaction"]) 
satisfactionDM_SM_CI  <- meanCI(afterDM_satisfaction_data_SM[,"satisfaction"]) 
satisfactionDM_TV_CI  <- meanCI( afterDM_satisfaction_data_TV[,"satisfaction"]) 

# Ploting all CI
results <- data.frame(label = "DM PC Satisfaction" , point = satisfactionDM_PC_CI[1], ci.lower = satisfactionDM_PC_CI[2], ci.upper = satisfactionDM_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "DM SM Satisfaction" , point = satisfactionDM_SM_CI[1], ci.lower = satisfactionDM_SM_CI[2], ci.upper = satisfactionDM_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM TV Satisfaction" , point = satisfactionDM_TV_CI[1], ci.lower = satisfactionDM_TV_CI[2], ci.upper = satisfactionDM_TV_CI[3], type='Other'))  

results2 <-data.frame(label = "DM PC-SM Satisfaction Difference " , point = satisfactionDM_diff_PC_SM_CI[1], ci.lower = satisfactionDM_diff_PC_SM_CI[2], ci.upper = satisfactionDM_diff_PC_SM_CI[3], type='Other')
results2 <- rbind(results2, data.frame(label = "DM PC-TV Satisfaction Difference " , point = satisfactionDM_diff_PC_TV_CI[1], ci.lower = satisfactionDM_diff_PC_TV_CI[2], ci.upper = satisfactionDM_diff_PC_TV_CI[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "DM SM-TV Satisfaction Difference " , point = satisfactionDM_diff_SM_TV_CI[1], ci.lower = satisfactionDM_diff_SM_TV_CI[2], ci.upper = satisfactionDM_diff_SM_TV_CI[3], type='Other'))  

plot    <- plotAllCI_likertScale(results)
plot

plot    <- plotAllCI(results2, plotRange = c(-4, 4))
plot


# Printing exact values
satisfactionDM_diff_PC_SM_CIform  <- format_ci( satisfactionDM_diff_PC_SM_CI, digits, width = NA, FALSE)
satisfactionDM_diff_PC_TV_CIform  <- format_ci( satisfactionDM_diff_PC_TV_CI, digits, width = NA, FALSE)
satisfactionDM_diff_SM_TV_CIform  <- format_ci( satisfactionDM_diff_SM_TV_CI, digits, width = NA, FALSE)

satisfactionDM_PC_CIform  <- format_ci( satisfactionDM_PC_CI, digits, width = NA, FALSE)
satisfactionDM_SM_CIform  <- format_ci( satisfactionDM_SM_CI, digits, width = NA, FALSE)
satisfactionDM_TV_CIform  <- format_ci( satisfactionDM_TV_CI, digits, width = NA, FALSE)

cat("\n1.# How do the three techniques perform in terms of choice satisfaction?")
cat("\n2. DM Satisfaction PC : ",satisfactionDM_PC_CIform)
cat("\n2. DM Satisfaction SM: " ,satisfactionDM_SM_CIform)
cat("\n2. DM Satisfaction TV: " ,satisfactionDM_TV_CIform)
cat("\n2. DM Satisfaction Difference PC-SM: ",satisfactionDM_diff_PC_SM_CIform)
cat("\n2. DM Satisfaction Difference PC-TV: ",satisfactionDM_diff_PC_TV_CIform)
cat("\n2. DM Satisfaction Difference SM-TV: ",satisfactionDM_diff_SM_TV_CIform)

