# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of speed in DM task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#

#rm(list = ls()) # clean up R's memory

source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.

# How do the three techniques perform in terms of speed in DM task?
DMtask_data <- read.csv("results/index_participant_to_task_dms_p21.csv") 
DMtask_data <- mergeStartEndColumnsToDuration(DMtask_data)
DMtask_data_PC <- averagePerParticipantDM(DMtask_data, "PC")
DMtask_data_SM <- averagePerParticipantDM(DMtask_data, "SM")
DMtask_data_TV <- averagePerParticipantDM(DMtask_data,"TV")
vall <-rbind(DMtask_data_PC, DMtask_data_SM, DMtask_data_TV)

DMtask_mean_PC  <- exp(meanCI.normal(DMtask_data_PC))
DMtask_mean_SM  <- exp(meanCI.normal(DMtask_data_SM))
DMtask_mean_TV  <- exp(meanCI.normal(DMtask_data_TV)) 

DMtask_diff_PCminusSM  <- exp(meanCI.normal(DMtask_data_PC - DMtask_data_SM))
DMtask_diff_PCminusTV  <- exp(meanCI.normal(DMtask_data_PC - DMtask_data_TV))
DMtask_diff_SMminusTV  <- exp(meanCI.normal(DMtask_data_SM - DMtask_data_TV))


# Ploting all CI

results1 <- data.frame(label = "DM task: Mean time PC" , point = DMtask_mean_PC[1], ci.lower = DMtask_mean_PC[2], ci.upper = DMtask_mean_PC[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "DM task: Mean time SM" , point = DMtask_mean_SM[1], ci.lower = DMtask_mean_SM[2], ci.upper = DMtask_mean_SM[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "DM task: Mean time TV" , point = DMtask_mean_TV[1], ci.lower = DMtask_mean_TV[2], ci.upper = DMtask_mean_TV[3], type='Other'))  

results2 <- data.frame(label = "DM task: Ratio time PC/SM" , point = DMtask_diff_PCminusSM[1], ci.lower = DMtask_diff_PCminusSM[2], ci.upper = DMtask_diff_PCminusSM[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "DM task: Ratio time PC/TV" , point = DMtask_diff_PCminusTV[1], ci.lower = DMtask_diff_PCminusTV[2], ci.upper = DMtask_diff_PCminusTV[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "DM task: Ratio time SM/TV" , point = DMtask_diff_SMminusTV[1], ci.lower = DMtask_diff_SMminusTV[2], ci.upper = DMtask_diff_SMminusTV[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 200))
plot

plot    <- plotAllCI(results2, plotRange = c(0, 2.2))
plot

# Printing exact values

DMtask_mean_PC_CIform  <- format_ci( DMtask_mean_PC, digits, width = NA, FALSE)
DMtask_mean_SM_CIform   <- format_ci( DMtask_mean_SM, digits, width = NA, FALSE)
DMtask_mean_TV_CIform   <-format_ci( DMtask_mean_TV, digits, width = NA, FALSE)

DMtask_diff_PCminusSM_CIform    <- format_ci( DMtask_diff_PCminusSM, digits, width = NA, FALSE)
DMtask_diff_PCminusTV_CIform    <- format_ci( DMtask_diff_PCminusTV, digits, width = NA, FALSE)
DMtask_diff_SMminusTV_CIform    <- format_ci( DMtask_diff_SMminusTV, digits, width = NA, FALSE)

cat("\n1. How do the three techniques perform in terms of speed in DM task?")
cat("\n2. DM: Time in PC : " ,DMtask_mean_PC_CIform)
cat("\n2. DM: Time in SM : " ,DMtask_mean_SM_CIform)
cat("\n2. DM: Time  in TV : " ,DMtask_mean_TV_CIform)
cat("\n2. DM: Time Difference PC/SM: ",DMtask_diff_PCminusSM_CIform)
cat("\n2. DM: Time Difference PC/TV: ",DMtask_diff_PCminusTV_CIform)
cat("\n2. DM: Time Difference SM/TV: ",DMtask_diff_SMminusTV_CIform)
